@@ -19,7 +19,7 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-from mypy_boto3_secretsmanager.client import SecretsManagerClient as Client, SecretsManagerClient
+from mypy_boto3_secretsmanager.client import SecretsManagerClient, SecretsManagerClient as Client
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 
 
